<?php
namespace KnitPay\Extensions\MicroJobEngine;

use Pronamic\WordPress\Money\Currency;
use Pronamic\WordPress\Money\TaxedMoney;
use Pronamic\WordPress\Pay\Plugin;
use Pronamic\WordPress\Pay\Payments\Payment;
use ET_Cash;
use ET_Order;
use ET_PaymentVisitor;
use WP_User;

/**
 * Title: Micro Job Engine Visitor
 * Description:
 * Copyright: 2020-2021 Knit Pay
 * Company: Knit Pay
 *
 * @author  knitpay
 * @since   4.7.0
 */

class KnitPayVisitor extends ET_PaymentVisitor {

	protected $_payment_type = 'knit_pay';

	function setup_checkout( ET_Order $order ) {
		$setting = ae_get_option( 'knit_pay' );

		$config_id      = $setting['config_id'];
		$payment_method = '';

		// Use default gateway if no configuration has been set.
		if ( empty( $config_id ) ) {
			$config_id = get_option( 'pronamic_pay_config_id' );
		}

		$gateway = Plugin::get_gateway( $config_id );

		if ( ! $gateway ) {
			return false;
		}

		$gateway->set_payment_method( $payment_method );

		$order = $order->generate_data_to_pay();
		$payer = new WP_User( $order['payer'] );

		/**
		 * Build payment.
		 */
		$payment = new Payment();

		$payment->source    = 'microjobengine';
		$payment->source_id = $order['ID'];
		$payment->order_id  = $order['ID'];

		$payment->description = Helper::get_description( $order, $setting );

		$payment->title = Helper::get_title( $order );

		// Customer.
		$payment->set_customer( Helper::get_customer( $payer ) );

		// Address.
		$payment->set_billing_address( Helper::get_address( $payer ) );

		// Currency.
		$currency = Currency::get_instance( $order['currencyCodeType'] );

		// Amount.
		$payment->set_total_amount( new TaxedMoney( $order['total'], $currency ) );

		// Method.
		$payment->method = $payment_method;

		// Configuration.
		$payment->config_id = $config_id;

		try {
			$payment = Plugin::start_payment( $payment );

			$error = $gateway->get_error();

			if ( is_wp_error( $error ) ) {
				throw new \Exception( $error->get_error_message() );
			}

			$et_payment         = new ET_Cash( $this->_settings );
			$success_return_url = $et_payment->set_checkout();
			$payment->set_meta( 'success_return_url', $success_return_url );

			// Execute a redirect.
			$response = array(
				'url'    => $payment->get_pay_redirect_url(),
				'ACK'    => true,
				'extend' => false,
			);
		} catch ( \Exception $e ) {
			$response = array(
				'ACK' => false,
				'msg' => Plugin::get_default_error_message() . $e->getMessage(),
			);
		}

		return $response;
	}

	function do_checkout( ET_Order $order ) {}
}
